# Generated by roxygen2: do not edit by hand

S3method(predict,mlumr_fit)
S3method(print,mlumr_data)
S3method(print,mlumr_dic)
S3method(print,mlumr_fit)
S3method(print,mlumr_naive)
S3method(print,mlumr_stc)
S3method(prior_summary,default)
S3method(prior_summary,mlumr_fit)
S3method(summary,mlumr_fit)
S3method(summary,mlumr_naive)
S3method(summary,mlumr_stc)
export(add_integration)
export(calculate_dic)
export(calculate_loo)
export(calculate_waic)
export(check_integration)
export(combine_data)
export(compare_models)
export(conditional_effects)
export(conditional_predict)
export(dbern)
export(default_prior_beta)
export(default_prior_intercept)
export(default_prior_sigma)
export(distr)
export(marginal_effects)
export(mlumr)
export(mlumr_engine)
export(naive)
export(pbern)
export(prior_cauchy)
export(prior_exponential)
export(prior_normal)
export(prior_sensitivity)
export(prior_student_t)
export(prior_summary)
export(qbern)
export(set_agd)
export(set_ipd)
export(stc)
export(unnest_integration)
import(Rcpp)
import(methods)
importFrom(RcppParallel,RcppParallelLibs)
importFrom(rstantools,rstan_config)
importFrom(stats,as.formula)
importFrom(stats,binomial)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,cor)
importFrom(stats,dbinom)
importFrom(stats,dnorm)
importFrom(stats,gaussian)
importFrom(stats,glm)
importFrom(stats,pbinom)
importFrom(stats,plogis)
importFrom(stats,pnorm)
importFrom(stats,poisson)
importFrom(stats,predict)
importFrom(stats,qbinom)
importFrom(stats,qlogis)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,var)
importFrom(stats,vcov)
importFrom(stats,weighted.mean)
useDynLib(mlumr, .registration = TRUE)
