# Generated by rstantools.  Do not edit by hand.

# names of stan models
stanmodels <- c("mlumr_binary_relaxed", "mlumr_binary_spfa", "mlumr_normal_relaxed", "mlumr_normal_spfa", "mlumr_poisson_relaxed", "mlumr_poisson_spfa")

# load each stan module
Rcpp::loadModule("stan_fit4mlumr_binary_relaxed_mod", what = TRUE)
Rcpp::loadModule("stan_fit4mlumr_binary_spfa_mod", what = TRUE)
Rcpp::loadModule("stan_fit4mlumr_normal_relaxed_mod", what = TRUE)
Rcpp::loadModule("stan_fit4mlumr_normal_spfa_mod", what = TRUE)
Rcpp::loadModule("stan_fit4mlumr_poisson_relaxed_mod", what = TRUE)
Rcpp::loadModule("stan_fit4mlumr_poisson_spfa_mod", what = TRUE)

# instantiate each stanmodel object
stanmodels <- sapply(stanmodels, function(model_name) {
  # create C++ code for stan model
  stan_file <- if(dir.exists("stan")) "stan" else file.path("inst", "stan")
  stan_file <- file.path(stan_file, paste0(model_name, ".stan"))
  stanfit <- rstan::stanc_builder(stan_file,
                                  allow_undefined = TRUE,
                                  obfuscate_model_name = FALSE)
  stanfit$model_cpp <- list(model_cppname = stanfit$model_name,
                            model_cppcode = stanfit$cppcode)
  # create stanmodel object
  methods::new(Class = "stanmodel",
               model_name = stanfit$model_name,
               model_code = stanfit$model_code,
               model_cpp = stanfit$model_cpp,
               mk_cppmodule = function(x) get(paste0("rstantools_model_", model_name)))
})
