% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/integration.R
\name{.transform_integration_points}
\alias{.transform_integration_points}
\title{Transform uniform integration points to covariate scales}
\usage{
.transform_integration_points(u_cor, data, ds, cov_names, n_int, n_cov)
}
\description{
Transform uniform integration points to covariate scales
}
\keyword{internal}
