% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.validate_ipd_finite_columns}
\alias{.validate_ipd_finite_columns}
\title{Validate finite IPD outcome and exposure values}
\usage{
.validate_ipd_finite_columns(data, outcome, exposure, family)
}
\description{
Validate finite IPD outcome and exposure values
}
\keyword{internal}
