% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/priors.R
\name{stan_prior_fields}
\alias{stan_prior_fields}
\title{Translate a scalar prior spec to the Stan data fields}
\usage{
stan_prior_fields(prior)
}
\arguments{
\item{prior}{A prior list.}
}
\value{
A list with \code{mean}, \code{sd}, \code{dist}, \code{df}.
}
\description{
Stan scalar-prior fields: \verb{prior_*_mean}, \verb{prior_*_sd},
\verb{prior_*_dist} (0 = normal, 1 = student_t, 2 = exponential for sigma
only), \verb{prior_*_df} (used only when dist == 1; positive placeholder
otherwise).
}
\keyword{internal}
