% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mlumr.R
\name{.validate_mlumr_integer}
\alias{.validate_mlumr_integer}
\title{Validate an integer-like mlumr() argument}
\usage{
.validate_mlumr_integer(x, name, lower)
}
\description{
Validate an integer-like mlumr() argument
}
\keyword{internal}
