% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{.nonnegative_variance}
\alias{.nonnegative_variance}
\title{Truncate tiny negative variance estimates caused by numerical noise}
\usage{
.nonnegative_variance(x, name = "variance", tol = 1e-10)
}
\description{
Truncate tiny negative variance estimates caused by numerical noise
}
\keyword{internal}
