% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stc.R
\name{.stc_binomial_comparator_delta}
\alias{.stc_binomial_comparator_delta}
\title{Comparator-population delta-method terms for binomial STC}
\usage{
.stc_binomial_comparator_delta(
  fit,
  newdata,
  weights,
  beta_hat,
  V,
  link_resolved,
  p_A,
  p_B,
  n_B
)
}
\description{
Comparator-population delta-method terms for binomial STC
}
\keyword{internal}
