% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.warn_constant_ipd_covariates}
\alias{.warn_constant_ipd_covariates}
\title{Warn when IPD covariates have no empirical variation}
\usage{
.warn_constant_ipd_covariates(data, covariates)
}
\description{
Warn when IPD covariates have no empirical variation
}
\keyword{internal}
