% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.validate_single_treatment}
\alias{.validate_single_treatment}
\title{Validate a data source contains only one treatment}
\usage{
.validate_single_treatment(data, treatment, label)
}
\description{
Validate a data source contains only one treatment
}
\keyword{internal}
