% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.validate_agd_poisson_outcomes}
\alias{.validate_agd_poisson_outcomes}
\title{Validate Poisson AgD outcomes}
\usage{
.validate_agd_poisson_outcomes(r_vals, E_vals)
}
\description{
Validate Poisson AgD outcomes
}
\keyword{internal}
