% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{.bounded_wald_interval}
\alias{.bounded_wald_interval}
\title{Bound a Wald interval to a valid numerical range}
\usage{
.bounded_wald_interval(center, se, z, lower = -Inf, upper = Inf)
}
\description{
Bound a Wald interval to a valid numerical range
}
\keyword{internal}
