% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics.R
\name{.diagnostic_count}
\alias{.diagnostic_count}
\title{Read a non-negative scalar diagnostic count}
\usage{
.diagnostic_count(x)
}
\description{
Read a non-negative scalar diagnostic count
}
\keyword{internal}
