% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/integration.R
\name{.validate_integration_distributions}
\alias{.validate_integration_distributions}
\title{Validate integration distributions against the combined data}
\usage{
.validate_integration_distributions(ds, data)
}
\description{
Validate integration distributions against the combined data
}
\keyword{internal}
