% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/conditional_effects.R
\name{.conditional_parameters}
\alias{.conditional_parameters}
\title{Extract posterior parameter draws for conditional summaries}
\usage{
.conditional_parameters(object, covariates)
}
\description{
Extract posterior parameter draws for conditional summaries
}
\keyword{internal}
