% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mlumr.R
\name{.resolve_mlumr_engine}
\alias{.resolve_mlumr_engine}
\title{Resolve and validate mlumr() backend engine}
\usage{
.resolve_mlumr_engine(engine)
}
\description{
Resolve and validate mlumr() backend engine
}
\keyword{internal}
