% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/predict.R
\name{.validate_mlumr_fit_object}
\alias{.validate_mlumr_fit_object}
\title{Validate an mlumr fit object}
\usage{
.validate_mlumr_fit_object(object)
}
\description{
Validate an mlumr fit object
}
\keyword{internal}
