% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/link_functions.R
\name{binomial_link_variance}
\alias{binomial_link_variance}
\title{Delta-method variance for a transformed binomial proportion}
\usage{
binomial_link_variance(p, n, link = c("logit", "probit", "cloglog"))
}
\description{
Delta-method variance for a transformed binomial proportion
}
\keyword{internal}
