% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/integration.R
\name{.int_stats}
\alias{.int_stats}
\title{Compute summary statistics for integration points}
\usage{
.int_stats(X_int, cov_names, n_agd)
}
\description{
Compute summary statistics for integration points
}
\keyword{internal}
