% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.validate_agd_binary_covariates}
\alias{.validate_agd_binary_covariates}
\title{Validate binary AgD covariate summaries}
\usage{
.validate_agd_binary_covariates(data, cov_means, cov_sds, cov_types)
}
\description{
Validate binary AgD covariate summaries
}
\keyword{internal}
