% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/integration.R
\name{.resolve_integration_cor}
\alias{.resolve_integration_cor}
\title{Resolve raw and copula correlation matrices for integration}
\usage{
.resolve_integration_cor(data, cov_names, n_cov, cor, cor_adjust, ds, verbose)
}
\description{
Resolve raw and copula correlation matrices for integration
}
\keyword{internal}
