% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.check_required_columns}
\alias{.check_required_columns}
\title{Validate that required columns are present}
\usage{
.check_required_columns(data, required_cols)
}
\description{
Validate that required columns are present
}
\keyword{internal}
