% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/priors.R
\name{is_single_prior}
\alias{is_single_prior}
\title{Is this object a single prior (vs a list of priors)?}
\usage{
is_single_prior(x)
}
\description{
Is this object a single prior (vs a list of priors)?
}
\keyword{internal}
