% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/integration.R
\name{.ensure_positive_definite_cor}
\alias{.ensure_positive_definite_cor}
\title{Ensure adjusted integration correlation is positive definite}
\usage{
.ensure_positive_definite_cor(copula_cor, n_cov)
}
\description{
Ensure adjusted integration correlation is positive definite
}
\keyword{internal}
