% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/predict.R
\name{.validate_summary_flag}
\alias{.validate_summary_flag}
\title{Validate a scalar summary flag}
\usage{
.validate_summary_flag(summary)
}
\description{
Validate a scalar summary flag
}
\keyword{internal}
