% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{pbern}
\alias{pbern}
\title{Bernoulli CDF}
\usage{
pbern(q, prob, lower.tail = TRUE, log.p = FALSE)
}
\arguments{
\item{q}{Vector of quantiles}

\item{prob}{Success probability}

\item{lower.tail}{Logical}

\item{log.p}{Logical}
}
\value{
Numeric vector
}
\description{
Bernoulli CDF
}
