% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/integration.R
\name{.validate_computed_integration_cor}
\alias{.validate_computed_integration_cor}
\title{Validate an IPD-derived correlation matrix before copula adjustment}
\usage{
.validate_computed_integration_cor(cor)
}
\description{
Validate an IPD-derived correlation matrix before copula adjustment
}
\keyword{internal}
