% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mlumr.R
\name{.validate_mlumr_sampling_args}
\alias{.validate_mlumr_sampling_args}
\title{Validate mlumr() sampler controls before backend dispatch}
\usage{
.validate_mlumr_sampling_args(
  chains,
  iter,
  warmup,
  seed,
  adapt_delta,
  max_treedepth,
  refresh
)
}
\description{
Validate mlumr() sampler controls before backend dispatch
}
\keyword{internal}
