% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/link_functions.R
\name{.validate_numeric_vector}
\alias{.validate_numeric_vector}
\title{Validate a numeric vector}
\usage{
.validate_numeric_vector(x, name)
}
\description{
Validate a numeric vector
}
\keyword{internal}
