% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/conditional_effects.R
\name{.conditional_profiles}
\alias{.conditional_profiles}
\title{Build covariate profiles for conditional summaries}
\usage{
.conditional_profiles(object, newdata = NULL)
}
\description{
Build covariate profiles for conditional summaries
}
\keyword{internal}
