% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/integration.R
\name{.attach_integration_points}
\alias{.attach_integration_points}
\title{Attach generated integration points to an mlumr_data object}
\usage{
.attach_integration_points(
  data,
  X_int_array,
  n_int,
  cor,
  copula_cor,
  cor_adjust
)
}
\description{
Attach generated integration points to an mlumr_data object
}
\keyword{internal}
