% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/priors.R
\name{validate_prior}
\alias{validate_prior}
\title{Validate prior specification}
\usage{
validate_prior(prior, param_name = "parameter")
}
\arguments{
\item{prior}{Prior specification list}

\item{param_name}{Parameter name for error messages}
}
\description{
Validate prior specification
}
\keyword{internal}
