% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stc.R
\name{.stc_agd_mean_newdata}
\alias{.stc_agd_mean_newdata}
\title{Build comparator-population covariates from AgD means}
\usage{
.stc_agd_mean_newdata(agd, cov_names)
}
\description{
Build comparator-population covariates from AgD means
}
\keyword{internal}
