% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{combine_data}
\alias{combine_data}
\title{Combine IPD and AgD for unanchored comparison}
\usage{
combine_data(ipd, agd)
}
\arguments{
\item{ipd}{An \code{mlumr_ipd} object from \code{\link[=set_ipd]{set_ipd()}}}

\item{agd}{An \code{mlumr_agd} object from \code{\link[=set_agd]{set_agd()}}}
}
\value{
An object of class \code{mlumr_data}
}
\description{
Combine IPD and AgD for unanchored comparison
}
\examples{
\dontrun{
dat <- combine_data(ipd, agd)
}
}
