% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics.R
\name{.validate_diagnostic_choice}
\alias{.validate_diagnostic_choice}
\title{Validate a diagnostics/model-comparison choice}
\usage{
.validate_diagnostic_choice(x, choices, name)
}
\description{
Validate a diagnostics/model-comparison choice
}
\keyword{internal}
