% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/conditional_effects.R
\name{.conditional_effect_choices}
\alias{.conditional_effect_choices}
\title{Conditional effect choices by family}
\usage{
.conditional_effect_choices(family)
}
\description{
Conditional effect choices by family
}
\keyword{internal}
