% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{eval_distr}
\alias{eval_distr}
\title{Evaluate a mlumr_distr object with data context}
\usage{
eval_distr(d, p, data = list())
}
\arguments{
\item{d}{A \code{mlumr_distr} object}

\item{p}{Vector of probabilities}

\item{data}{A named list or data frame to evaluate expressions in}
}
\value{
Numeric vector of quantiles
}
\description{
Evaluate a mlumr_distr object with data context
}
\keyword{internal}
