% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/engine.R
\name{.cmdstan_available}
\alias{.cmdstan_available}
\title{Check whether CmdStan is configured for cmdstanr}
\usage{
.cmdstan_available()
}
\description{
Check whether CmdStan is configured for cmdstanr
}
\keyword{internal}
