% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{.sqrt_variance}
\alias{.sqrt_variance}
\title{Square root of a variance estimate with numerical guarding}
\usage{
.sqrt_variance(x, name = "variance", tol = 1e-10)
}
\description{
Square root of a variance estimate with numerical guarding
}
\keyword{internal}
