% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.standardize_ipd_data}
\alias{.standardize_ipd_data}
\title{Standardize IPD to mlumr's internal column contract}
\usage{
.standardize_ipd_data(
  data,
  treatment,
  outcome,
  covariates,
  family,
  exposure = NULL,
  study = NULL
)
}
\description{
Standardize IPD to mlumr's internal column contract
}
\keyword{internal}
