% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.agd_outcome_summary}
\alias{.agd_outcome_summary}
\title{Summarize AgD outcomes}
\usage{
.agd_outcome_summary(
  data,
  family,
  outcome_n,
  outcome_r,
  outcome_mean,
  outcome_se,
  outcome_E
)
}
\description{
Summarize AgD outcomes
}
\keyword{internal}
