% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/link_functions.R
\name{mlumr_message}
\alias{mlumr_message}
\title{Emit package progress messages when enabled}
\usage{
mlumr_message(..., verbose = TRUE)
}
\description{
Emit package progress messages when enabled
}
\keyword{internal}
