% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.validate_non_empty_data}
\alias{.validate_non_empty_data}
\title{Validate that input data contain at least one row}
\usage{
.validate_non_empty_data(data, label)
}
\description{
Validate that input data contain at least one row
}
\keyword{internal}
