% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.validate_agd_binomial_outcomes}
\alias{.validate_agd_binomial_outcomes}
\title{Validate binomial AgD outcomes}
\usage{
.validate_agd_binomial_outcomes(r_vals, n_vals)
}
\description{
Validate binomial AgD outcomes
}
\keyword{internal}
