% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mlumr.R
\name{.mlumr_fit_backend}
\alias{.mlumr_fit_backend}
\title{Dispatch mlumr() sampling to the selected backend}
\usage{
.mlumr_fit_backend(
  engine,
  model_name,
  stan_data,
  chains,
  iter,
  warmup,
  seed,
  adapt_delta,
  max_treedepth,
  refresh,
  ...
)
}
\description{
Dispatch mlumr() sampling to the selected backend
}
\keyword{internal}
