% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics.R
\name{.ordered_log_lik_columns}
\alias{.ordered_log_lik_columns}
\title{Ordered pointwise log-likelihood columns for one data source}
\usage{
.ordered_log_lik_columns(draws, source)
}
\description{
Ordered pointwise log-likelihood columns for one data source
}
\keyword{internal}
