% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/integration.R
\name{.int_cor_stats}
\alias{.int_cor_stats}
\title{Pairwise-correlation diagnostics for integration points}
\usage{
.int_cor_stats(X_orig, X_double, cov_names, n_agd, cor_target = NULL)
}
\description{
Pairwise-correlation diagnostics for integration points
}
\keyword{internal}
