% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.validate_agd_outcome_args}
\alias{.validate_agd_outcome_args}
\title{Validate AgD outcome column arguments}
\usage{
.validate_agd_outcome_args(
  family,
  outcome_n,
  outcome_r,
  outcome_mean,
  outcome_se,
  outcome_E
)
}
\description{
Validate AgD outcome column arguments
}
\keyword{internal}
