% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics.R
\name{.validate_model_count}
\alias{.validate_model_count}
\title{Validate that model comparison has at least two candidates}
\usage{
.validate_model_count(models)
}
\description{
Validate that model comparison has at least two candidates
}
\keyword{internal}
