% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{get_distribution_type}
\alias{get_distribution_type}
\title{Get distribution type (continuous, discrete, or binary)}
\usage{
get_distribution_type(..., data = list())
}
\arguments{
\item{...}{distr() objects}

\item{data}{Sample data for evaluation}
}
\value{
Named character vector
}
\description{
Get distribution type (continuous, discrete, or binary)
}
\keyword{internal}
