% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/priors.R
\name{prior_student_t}
\alias{prior_student_t}
\title{Specify a Student-t prior}
\usage{
prior_student_t(df = 5, mean = 0, sd = 2.5, autoscale = FALSE)
}
\arguments{
\item{df}{Degrees of freedom (must be positive). Values in \code{3:7} are
recommended for logistic-regression coefficients.}

\item{mean}{Prior location (default 0).}

\item{sd}{Prior scale (default 2.5).}

\item{autoscale}{See \code{\link[=prior_normal]{prior_normal()}}. Default \code{FALSE}.}
}
\value{
A list with components \code{distribution = "student_t"}, \code{df},
\code{mean}, \code{sd}, \code{autoscale}.
}
\description{
Heavier-tailed alternative to \code{\link[=prior_normal]{prior_normal()}}. For logistic-regression
coefficients with unit-scale predictors, the Stan community prior-choice
recommendations suggest Student-t with \code{df} between 3 and 7 as a robust
weakly informative prior (Gelman et al., 2008).
}
\examples{
# Gelman et al. 2008 recommendation for logistic-regression coefficients
prior_student_t(df = 5, mean = 0, sd = 2.5)
}
