% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics.R
\name{.validate_log_lik_matrix}
\alias{.validate_log_lik_matrix}
\title{Validate a pointwise log-likelihood matrix}
\usage{
.validate_log_lik_matrix(log_lik)
}
\description{
Validate a pointwise log-likelihood matrix
}
\keyword{internal}
