% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mlumr.R
\name{.mlumr_prior_metadata}
\alias{.mlumr_prior_metadata}
\title{Store user priors plus the resolved Stan-scale beta prior}
\usage{
.mlumr_prior_metadata(
  data,
  family,
  prior_intercept,
  prior_beta,
  prior_sigma,
  beta_fields,
  sd_x
)
}
\description{
Store user priors plus the resolved Stan-scale beta prior
}
\keyword{internal}
