% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.validate_ipd_covariates}
\alias{.validate_ipd_covariates}
\title{Validate IPD covariates}
\usage{
.validate_ipd_covariates(data, covariates)
}
\description{
Validate IPD covariates
}
\keyword{internal}
