% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/prior_summary.R
\name{.validate_prior_summary_digits}
\alias{.validate_prior_summary_digits}
\title{Validate prior_summary digits}
\usage{
.validate_prior_summary_digits(digits)
}
\description{
Validate prior_summary digits
}
\keyword{internal}
