% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stc.R
\name{.stc_formula}
\alias{.stc_formula}
\title{Build the STC GLM formula without assuming syntactic covariate names}
\usage{
.stc_formula(cov_names, family)
}
\description{
Build the STC GLM formula without assuming syntactic covariate names
}
\keyword{internal}
