% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/predict.R
\name{.validate_predict_choice}
\alias{.validate_predict_choice}
\title{Validate an exact scalar prediction argument}
\usage{
.validate_predict_choice(x, choices, name)
}
\description{
Validate an exact scalar prediction argument
}
\keyword{internal}
