% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mlumr.R
\name{.mlumr_build_stan_data}
\alias{.mlumr_build_stan_data}
\title{Build the Stan data list for mlumr()}
\usage{
.mlumr_build_stan_data(
  data,
  family,
  link_info,
  prior_intercept,
  prior_beta,
  prior_sigma
)
}
\description{
Build the Stan data list for mlumr()
}
\keyword{internal}
