% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.strip_agd_cov_suffix}
\alias{.strip_agd_cov_suffix}
\title{Strip AgD covariate suffixes}
\usage{
.strip_agd_cov_suffix(cov_means)
}
\description{
Strip AgD covariate suffixes
}
\keyword{internal}
