% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.validate_reserved_internal_names}
\alias{.validate_reserved_internal_names}
\title{Reject user names that would overwrite standardized internal columns}
\usage{
.validate_reserved_internal_names(user_names, reserved, label)
}
\description{
Reject user names that would overwrite standardized internal columns
}
\keyword{internal}
