% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{cor_adjust_spearman}
\alias{cor_adjust_spearman}
\title{Convert Spearman correlations to Gaussian copula correlations}
\usage{
cor_adjust_spearman(X, types)
}
\arguments{
\item{X}{Correlation matrix (Spearman)}

\item{types}{Character vector of distribution types}
}
\value{
Adjusted correlation matrix for Gaussian copula
}
\description{
Applies theoretical relationships between Spearman's rho and the
Gaussian copula parameter (Kurowicka & Cooke, 2006; Lebrun & Dutfoy, 2009):
\itemize{
\item Continuous-continuous: rho_copula = 2 * sin(pi * rho_S / 6) (exact)
\item Binary-binary: rho_copula = sin(pi * rho_S / 2) (heuristic; the exact
relationship depends on marginal prevalences, not accounted for here)
\item Continuous-binary: rho_copula = sqrt(2) * sin(pi * rho_S / (2*sqrt(3)))
(heuristic)
}
}
\keyword{internal}
