% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/prior_summary.R
\name{.resolved_prior_family_label}
\alias{.resolved_prior_family_label}
\title{Label a resolved Stan prior family code}
\usage{
.resolved_prior_family_label(dist)
}
\description{
Label a resolved Stan prior family code
}
\keyword{internal}
