% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/link_functions.R
\name{.validate_positive_numeric}
\alias{.validate_positive_numeric}
\title{Validate positive finite numeric input}
\usage{
.validate_positive_numeric(x, name)
}
\description{
Validate positive finite numeric input
}
\keyword{internal}
