% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/engine.R
\name{get_engine}
\alias{get_engine}
\title{Get the current Stan engine (internal)}
\usage{
get_engine()
}
\description{
Get the current Stan engine (internal)
}
\keyword{internal}
