% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/predict.R
\name{.require_draw_columns}
\alias{.require_draw_columns}
\title{Require posterior draw columns}
\usage{
.require_draw_columns(draws, columns, context)
}
\description{
Require posterior draw columns
}
\keyword{internal}
