% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/link_functions.R
\name{link_fun}
\alias{link_fun}
\title{Link function (response scale -> linear predictor)}
\usage{
link_fun(x, link = c("identity", "log", "logit", "probit", "cloglog"))
}
\arguments{
\item{x}{Numeric vector on response scale}

\item{link}{Character: link function name}
}
\value{
Numeric vector on linear predictor scale
}
\description{
Link function (response scale -> linear predictor)
}
\keyword{internal}
