% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/integration.R
\name{.validate_integration_cor}
\alias{.validate_integration_cor}
\title{Validate a user-supplied integration correlation matrix}
\usage{
.validate_integration_cor(cor, n_cov, cov_names = NULL)
}
\description{
Validate a user-supplied integration correlation matrix
}
\keyword{internal}
