% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/integration.R
\name{.generate_copula_uniforms}
\alias{.generate_copula_uniforms}
\title{Generate correlated uniform quasi-Monte Carlo points}
\usage{
.generate_copula_uniforms(n_int, n_cov, copula_cor)
}
\description{
Generate correlated uniform quasi-Monte Carlo points
}
\keyword{internal}
