% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stc.R
\name{.stc_comparator_data}
\alias{.stc_comparator_data}
\title{Build comparator-population covariates for STC prediction}
\usage{
.stc_comparator_data(data, cov_names, family)
}
\description{
Build comparator-population covariates for STC prediction
}
\keyword{internal}
