% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stc.R
\name{.stc_glm_parameters}
\alias{.stc_glm_parameters}
\title{Validate fitted STC GLM parameters before delta-method calculations}
\usage{
.stc_glm_parameters(fit)
}
\description{
Validate fitted STC GLM parameters before delta-method calculations
}
\keyword{internal}
