% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/link_functions.R
\name{bound_probability}
\alias{bound_probability}
\title{Bound probabilities away from 0 and 1}
\usage{
bound_probability(p, n, min_count = 0.5)
}
\description{
Bound probabilities away from 0 and 1
}
\keyword{internal}
