% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/backend_cmdstanr.R
\name{fit_cmdstanr}
\alias{fit_cmdstanr}
\title{Fit a Stan model using cmdstanr}
\usage{
fit_cmdstanr(
  model_name,
  stan_data,
  chains,
  iter,
  warmup,
  seed,
  adapt_delta,
  max_treedepth,
  refresh,
  ...
)
}
\description{
Fit a Stan model using cmdstanr
}
\keyword{internal}
