% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.agd_cov_info}
\alias{.agd_cov_info}
\title{Build AgD covariate metadata}
\usage{
.agd_cov_info(cov_names, cov_sds, cov_types)
}
\description{
Build AgD covariate metadata
}
\keyword{internal}
