% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/prior_summary.R
\name{.validate_resolved_beta_prior}
\alias{.validate_resolved_beta_prior}
\title{Validate resolved beta-prior metadata stored on a fit}
\usage{
.validate_resolved_beta_prior(br)
}
\description{
Validate resolved beta-prior metadata stored on a fit
}
\keyword{internal}
