% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics.R
\name{.log_lik_column_index}
\alias{.log_lik_column_index}
\title{Extract integer indexes from Stan vector column names}
\usage{
.log_lik_column_index(cols, source)
}
\description{
Extract integer indexes from Stan vector column names
}
\keyword{internal}
