% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{eval_distr_arg}
\alias{eval_distr_arg}
\title{Evaluate a single mlumr_distr argument expression}
\usage{
eval_distr_arg(expr, data)
}
\arguments{
\item{expr}{An unevaluated expression}

\item{data}{Data context}
}
\value{
Evaluated value
}
\description{
Evaluate a single mlumr_distr argument expression
}
\keyword{internal}
