% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{qbern}
\alias{qbern}
\title{Bernoulli quantile function}
\usage{
qbern(p, prob, lower.tail = TRUE, log.p = FALSE)
}
\arguments{
\item{p}{Vector of probabilities}

\item{prob}{Success probability}

\item{lower.tail}{Logical; if TRUE, probabilities are P(X <= x)}

\item{log.p}{Logical; if TRUE, probabilities are given as log(p)}
}
\value{
Integer vector of 0s and 1s
}
\description{
Bernoulli quantile function
}
