% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/predict.R
\name{.validate_effect_choice}
\alias{.validate_effect_choice}
\title{Validate a scalar marginal-effect choice}
\usage{
.validate_effect_choice(effect)
}
\description{
Validate a scalar marginal-effect choice
}
\keyword{internal}
