% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/engine.R
\name{.validate_engine_name}
\alias{.validate_engine_name}
\title{Validate a Stan engine name}
\usage{
.validate_engine_name(engine)
}
\description{
Validate a Stan engine name
}
\keyword{internal}
