% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/backend_cmdstanr.R
\name{.cmdstanr_cache_root}
\alias{.cmdstanr_cache_root}
\title{Resolve a writable cmdstanr cache root}
\usage{
.cmdstanr_cache_root()
}
\description{
Resolve a writable cmdstanr cache root
}
\keyword{internal}
