% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics.R
\name{.mlumr_model_label}
\alias{.mlumr_model_label}
\title{Human-readable model label for an mlumr fit or DIC object}
\usage{
.mlumr_model_label(object)
}
\description{
Human-readable model label for an mlumr fit or DIC object
}
\keyword{internal}
