% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.ipd_required_columns}
\alias{.ipd_required_columns}
\title{Required source columns for IPD setup}
\usage{
.ipd_required_columns(
  treatment,
  outcome,
  covariates,
  exposure = NULL,
  study = NULL
)
}
\description{
Required source columns for IPD setup
}
\keyword{internal}
