% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{dbern}
\alias{dbern}
\title{Bernoulli PMF}
\usage{
dbern(x, prob, log = FALSE)
}
\arguments{
\item{x}{Vector of values}

\item{prob}{Success probability}

\item{log}{Logical; if TRUE, return log-density}
}
\value{
Numeric vector
}
\description{
Bernoulli PMF
}
