% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/prior_summary.R
\name{.resolved_prior_broadcast_label}
\alias{.resolved_prior_broadcast_label}
\title{Format a homogeneous resolved beta prior}
\usage{
.resolved_prior_broadcast_label(br, digits)
}
\description{
Format a homogeneous resolved beta prior
}
\keyword{internal}
