% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/link_functions.R
\name{.bound_unit_interval}
\alias{.bound_unit_interval}
\title{Bound probabilities to the open unit interval}
\usage{
.bound_unit_interval(p)
}
\description{
Bound probabilities to the open unit interval
}
\keyword{internal}
