% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/predict.R
\name{.validate_probs}
\alias{.validate_probs}
\title{Validate quantile probabilities}
\usage{
.validate_probs(probs)
}
\description{
Validate quantile probabilities
}
\keyword{internal}
