% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/link_functions.R
\name{inverse_link_derivative}
\alias{inverse_link_derivative}
\title{Derivative of inverse link with respect to linear predictor}
\usage{
inverse_link_derivative(
  eta,
  p = inverse_link(eta, link),
  link = c("logit", "probit", "cloglog")
)
}
\description{
Derivative of inverse link with respect to linear predictor
}
\keyword{internal}
