% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/backend_cmdstanr.R
\name{.cmdstanr_compile_dir}
\alias{.cmdstanr_compile_dir}
\title{Cache directory for cmdstanr-compiled model executables}
\usage{
.cmdstanr_compile_dir(model_name, stan_file)
}
\description{
Cache directory for cmdstanr-compiled model executables
}
\keyword{internal}
