% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/integration.R
\name{.adjust_integration_cor}
\alias{.adjust_integration_cor}
\title{Adjust correlations to Gaussian-copula scale}
\usage{
.adjust_integration_cor(cor, cor_adjust, dtypes)
}
\description{
Adjust correlations to Gaussian-copula scale
}
\keyword{internal}
