% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.drop_missing_rows}
\alias{.drop_missing_rows}
\title{Drop rows with missing setup inputs}
\usage{
.drop_missing_rows(data, required_cols)
}
\description{
Drop rows with missing setup inputs
}
\keyword{internal}
