% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.validate_agd_sample_size}
\alias{.validate_agd_sample_size}
\title{Validate optional AgD sample sizes}
\usage{
.validate_agd_sample_size(n_vals)
}
\description{
Validate optional AgD sample sizes
}
\keyword{internal}
