% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stc.R
\name{.stc_model_matrix}
\alias{.stc_model_matrix}
\title{Build a model matrix aligned with fitted GLM coefficients}
\usage{
.stc_model_matrix(fit, newdata)
}
\description{
Build a model matrix aligned with fitted GLM coefficients
}
\keyword{internal}
