% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mlumr.R
\name{.mlumr_log_fit_start}
\alias{.mlumr_log_fit_start}
\title{Log mlumr() fit metadata}
\usage{
.mlumr_log_fit_start(model_name, family, link, stan_data, engine, verbose)
}
\description{
Log mlumr() fit metadata
}
\keyword{internal}
