% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.agd_covariate_spec}
\alias{.agd_covariate_spec}
\title{Normalize AgD covariate specification}
\usage{
.agd_covariate_spec(cov_means, cov_sds = NULL, cov_types = NULL)
}
\description{
Normalize AgD covariate specification
}
\keyword{internal}
