% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/engine.R
\name{.supported_engines}
\alias{.supported_engines}
\title{Supported Stan engines}
\usage{
.supported_engines()
}
\description{
Supported Stan engines
}
\keyword{internal}
