% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/prior_sensitivity.R
\name{.summarize_sensitivity}
\alias{.summarize_sensitivity}
\title{Summarize a sensitivity refit.}
\usage{
.summarize_sensitivity(fit, scale, probs)
}
\description{
Summarize a sensitivity refit.
}
\keyword{internal}
