% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{.validate_conf_level}
\alias{.validate_conf_level}
\title{Validate a confidence level}
\usage{
.validate_conf_level(conf_level)
}
\description{
Validate a confidence level
}
\keyword{internal}
