% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.validate_complete_rows_remain}
\alias{.validate_complete_rows_remain}
\title{Validate that complete-case filtering left rows to analyze}
\usage{
.validate_complete_rows_remain(data, label)
}
\description{
Validate that complete-case filtering left rows to analyze
}
\keyword{internal}
