% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/engine.R
\name{.message_engine_unchanged}
\alias{.message_engine_unchanged}
\title{Report that the current engine was not changed}
\usage{
.message_engine_unchanged()
}
\description{
Report that the current engine was not changed
}
\keyword{internal}
