% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.validate_agd_normal_outcomes}
\alias{.validate_agd_normal_outcomes}
\title{Validate normal AgD outcomes}
\usage{
.validate_agd_normal_outcomes(y_vals, se_vals)
}
\description{
Validate normal AgD outcomes
}
\keyword{internal}
