% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/conditional_effects.R
\name{.safe_positive_ratio}
\alias{.safe_positive_ratio}
\title{Ratio with the same positive-denominator guard used by Stan generated quantities}
\usage{
.safe_positive_ratio(num, denom)
}
\description{
Ratio with the same positive-denominator guard used by Stan generated quantities
}
\keyword{internal}
