% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{.z_from_conf_level}
\alias{.z_from_conf_level}
\title{Convert a confidence level to a two-sided normal critical value}
\usage{
.z_from_conf_level(conf_level)
}
\description{
Convert a confidence level to a two-sided normal critical value
}
\keyword{internal}
