% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics.R
\name{.comparison_names}
\alias{.comparison_names}
\title{Use user-supplied comparison names when available}
\usage{
.comparison_names(models, fallback)
}
\description{
Use user-supplied comparison names when available
}
\keyword{internal}
