% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{distr}
\alias{distr}
\title{Specify a marginal distribution}
\usage{
distr(qfun, ...)
}
\arguments{
\item{qfun}{Inverse CDF function (e.g., \code{qnorm}, \code{qbern})}

\item{...}{Parameters of the distribution, can reference column names in AgD}
}
\value{
A list with class \code{"mlumr_distr"} containing the distribution specification
}
\description{
Used to specify marginal distributions for covariates when adding integration
points. Wraps an inverse CDF (quantile) function with its parameters.
}
\examples{
# Normal distribution
distr(qnorm, mean = 0, sd = 1)

# Bernoulli distribution with probability 0.3
distr(qbern, prob = 0.3)
}
