% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.validate_agd_covariate_names}
\alias{.validate_agd_covariate_names}
\title{Validate AgD covariate names after suffix stripping}
\usage{
.validate_agd_covariate_names(cov_means)
}
\description{
Validate AgD covariate names after suffix stripping
}
\keyword{internal}
