% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/link_functions.R
\name{.validate_link_string}
\alias{.validate_link_string}
\title{Validate a scalar link/family string}
\usage{
.validate_link_string(x, name)
}
\description{
Validate a scalar link/family string
}
\keyword{internal}
