% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/link_functions.R
\name{link_derivative_response}
\alias{link_derivative_response}
\title{Derivative of a binomial link with respect to probability}
\usage{
link_derivative_response(p, link = c("logit", "probit", "cloglog"))
}
\description{
Derivative of a binomial link with respect to probability
}
\keyword{internal}
