% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/link_functions.R
\name{inverse_link}
\alias{inverse_link}
\title{Inverse link function (linear predictor -> response scale)}
\usage{
inverse_link(x, link = c("identity", "log", "logit", "probit", "cloglog"))
}
\arguments{
\item{x}{Numeric vector}

\item{link}{Character: link function name}
}
\value{
Numeric vector on response scale
}
\description{
Inverse link function (linear predictor -> response scale)
}
\keyword{internal}
