% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics.R
\name{.diagnostic_value}
\alias{.diagnostic_value}
\title{Format a diagnostic setting for warning messages}
\usage{
.diagnostic_value(x)
}
\description{
Format a diagnostic setting for warning messages
}
\keyword{internal}
