% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/integration.R
\name{.warn_integration_size}
\alias{.warn_integration_size}
\title{Warn when integration resolution is low for the covariate dimension}
\usage{
.warn_integration_size(n_int, n_cov)
}
\description{
Warn when integration resolution is low for the covariate dimension
}
\keyword{internal}
