% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/naive.R
\name{.naive_poisson}
\alias{.naive_poisson}
\title{Naive comparison for Poisson outcomes}
\usage{
.naive_poisson(data, ipd, agd, conf_level, z)
}
\description{
Naive comparison for Poisson outcomes
}
\keyword{internal}
