% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics.R
\name{calculate_waic}
\alias{calculate_waic}
\title{Calculate WAIC for an mlumr_fit}
\usage{
calculate_waic(object, ...)
}
\arguments{
\item{object}{An \code{mlumr_fit} object.}

\item{...}{Additional arguments passed to \code{\link[loo:waic]{loo::waic()}}.}
}
\value{
An object of class \code{waic} (see \code{\link[loo:waic]{loo::waic()}}).
}
\description{
Watanabe-Akaike Information Criterion (Watanabe 2010) based on the
pointwise log-likelihoods. WAIC is asymptotically equivalent to
LOO-CV; prefer \code{\link[=calculate_loo]{calculate_loo()}} when Pareto-k is well-behaved.
}
\note{
As with \code{\link[=calculate_loo]{calculate_loo()}}, each AgD row is treated as an
independent observation. WAIC will be optimistic for AgD rows
that share a study (see the note on \code{calculate_loo()}).
}
\examples{
\dontrun{
waic_spfa <- calculate_waic(fit_spfa)
}
}
