% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.validate_agd_cov_types}
\alias{.validate_agd_cov_types}
\title{Validate AgD covariate type labels}
\usage{
.validate_agd_cov_types(cov_types)
}
\description{
Validate AgD covariate type labels
}
\keyword{internal}
