% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{.validate_mlumr_data_object}
\alias{.validate_mlumr_data_object}
\title{Validate an mlumr_data object}
\usage{
.validate_mlumr_data_object(data)
}
\description{
Validate an mlumr_data object
}
\keyword{internal}
