% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.standardize_agd_data}
\alias{.standardize_agd_data}
\title{Standardize AgD to mlumr's internal column contract}
\usage{
.standardize_agd_data(
  data,
  treatment,
  family,
  outcome_n,
  outcome_r,
  outcome_mean,
  outcome_se,
  outcome_E,
  cov_means,
  cov_sds,
  cov_names,
  study = NULL
)
}
\description{
Standardize AgD to mlumr's internal column contract
}
\keyword{internal}
