% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/integration.R
\name{.validate_integration_args}
\alias{.validate_integration_args}
\title{Validate top-level integration arguments}
\usage{
.validate_integration_args(data, n_int, cor_adjust, verbose, ds)
}
\description{
Validate top-level integration arguments
}
\keyword{internal}
