% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.validate_ipd_outcome}
\alias{.validate_ipd_outcome}
\title{Validate IPD outcome and exposure columns}
\usage{
.validate_ipd_outcome(data, outcome, family, exposure = NULL)
}
\description{
Validate IPD outcome and exposure columns
}
\keyword{internal}
