% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics.R
\name{.relative_eff_from_log_lik}
\alias{.relative_eff_from_log_lik}
\title{Compute stable relative effective sample sizes from log-likelihoods}
\usage{
.relative_eff_from_log_lik(log_lik, chain_id)
}
\description{
Compute stable relative effective sample sizes from log-likelihoods
}
\keyword{internal}
