% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/conditional_effects.R
\name{.conditional_eta}
\alias{.conditional_eta}
\title{Compute conditional linear predictors for one profile}
\usage{
.conditional_eta(params, x)
}
\description{
Compute conditional linear predictors for one profile
}
\keyword{internal}
