% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics.R
\name{.finite_numeric_values}
\alias{.finite_numeric_values}
\title{Return finite numeric values from a summary column}
\usage{
.finite_numeric_values(x)
}
\description{
Return finite numeric values from a summary column
}
\keyword{internal}
