% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/prior_sensitivity.R
\name{.rescale_prior_beta}
\alias{.rescale_prior_beta}
\title{Rescale a prior_beta's scale, preserving family / mean / df.}
\usage{
.rescale_prior_beta(prior, new_scale)
}
\description{
Rescale a prior_beta's scale, preserving family / mean / df.
}
\keyword{internal}
