% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.agd_required_columns}
\alias{.agd_required_columns}
\title{AgD source columns required for setup}
\usage{
.agd_required_columns(
  treatment,
  cov_means,
  cov_sds,
  outcome_n = NULL,
  outcome_r = NULL,
  outcome_mean = NULL,
  outcome_se = NULL,
  outcome_E = NULL,
  study = NULL
)
}
\description{
AgD source columns required for setup
}
\keyword{internal}
