% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics.R
\name{check_diagnostics}
\alias{check_diagnostics}
\title{Check MCMC diagnostics and warn if issues found}
\usage{
check_diagnostics(fit)
}
\arguments{
\item{fit}{An \code{mlumr_fit} object}
}
\description{
Check MCMC diagnostics and warn if issues found
}
\keyword{internal}
