% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.is_whole_number_count}
\alias{.is_whole_number_count}
\title{Check whether values are valid non-negative whole-number counts}
\usage{
.is_whole_number_count(x, allow_missing = FALSE)
}
\description{
Check whether values are valid non-negative whole-number counts
}
\keyword{internal}
