% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stc.R
\name{.stc_normal}
\alias{.stc_normal}
\title{Normal-outcome STC estimator}
\usage{
.stc_normal(
  data,
  fit,
  ipd,
  agd,
  newdata,
  link_resolved,
  conf_level,
  z,
  beta_hat,
  V,
  n_int
)
}
\description{
Normal-outcome STC estimator
}
\keyword{internal}
