% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_setup.R
\name{.ipd_outcome_summary}
\alias{.ipd_outcome_summary}
\title{Summarize standardized IPD outcomes}
\usage{
.ipd_outcome_summary(ipd_data, family)
}
\description{
Summarize standardized IPD outcomes
}
\keyword{internal}
